@@ -304,6 +304,12 @@ void ActionManagerImpl::initMainWidget(MainWidget* mainWidget)
     connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenSelectedArticles()));
     action->setShortcuts(KShortcut( "Shift+Return" ));
 
+    action = coll->addAction("article_open_in_background" );
+    action->setIcon(KIcon("tab-new"));
+    action->setText(i18n("Open in Background Tab"));
+    connect(action, SIGNAL(triggered(bool)), d->mainWidget, SLOT(slotOpenSelectedArticlesInBackground()));
+    action->setShortcuts(KShortcut( "Return" ));
+
     action = coll->addAction("article_open_external" );
     action->setIcon(KIcon("window-new"));
     action->setText(i18n("Open in External Browser"));
@@ -563,6 +569,17 @@ void ActionManagerImpl::initTabWidget(TabWidget* tabWidget)
     action->setText(i18n("Shrink Font"));
     connect(action, SIGNAL(triggered(bool)), d->tabWidget, SLOT(slotFrameZoomOut()));
     action->setShortcut( QKeySequence::ZoomOut );
+
+    QString actionname;
+    for (int i=1;i<10;i++) {
+      actionname.sprintf("activate_tab_%02d", i);
+      action = new KAction( i18n("Activate Tab %1", i),this );
+      action->setShortcut( QKeySequence( QString::fromLatin1( "Alt+%1" ).arg( i ) ) );
+      coll->addAction( actionname, action );
+      connect( action, SIGNAL(triggered(bool)), d->tabWidget, SLOT(slotActivateTab()) );
+    }
+
+
 }
 
 void ActionManagerImpl::initFrameManager(FrameManager* frameManager)
@@ -625,6 +642,7 @@ void ActionManagerImpl::setArticleActionsEnabled( bool enabled ) {
     setActionEnabled("article_delete")
     setActionEnabled("file_sendlink")
     setActionEnabled("file_sendfile")
+    setActionEnabled("article_open_in_background")
 #undef setActionEnabled
 }
 
