@@ -71,13 +71,6 @@
 using namespace CalendarSupport;
 using namespace KHolidays;
 
-K_GLOBAL_STATIC( Akonadi::CollectionDialog, globalCollectionDialog )
-
-static Akonadi::CollectionDialog *collectionDialog()
-{
-  return globalCollectionDialog;
-}
-
 KCalCore::Incidence::Ptr CalendarSupport::incidence( const Akonadi::Item &item )
 {
   try {
@@ -398,8 +391,7 @@ Akonadi::Collection CalendarSupport::selectCollection( QWidget *parent,
                                                        const QStringList &mimeTypes,
                                                        const Akonadi::Collection &defCollection )
 {
-  Akonadi::CollectionDialog *dlg = collectionDialog(); //krazy:exclude=crashy
-  dlg->setParent( parent, Qt::Dialog );
+  QPointer<Akonadi::CollectionDialog> dlg( new Akonadi::CollectionDialog( parent ) );
   dlg->setCaption( i18n( "Select Calendar" ) );
   dlg->setDescription( i18n( "Select the calendar where this item will be stored." ) );
   dlg->changeCollectionDialogOptions( Akonadi::CollectionDialog::KeepTreeExpanded );
@@ -414,13 +406,14 @@ Akonadi::Collection CalendarSupport::selectCollection( QWidget *parent,
 
   // FIXME: don't use exec.
   dialogCode = dlg->exec();
-  if ( dialogCode == QDialog::Accepted ) {
+  if ( dlg && dialogCode == QDialog::Accepted ) {
     collection = dlg->selectedCollection();
 
     if ( !collection.isValid() ) {
       kWarning() << "An invalid collection was selected!";
     }
   }
+  delete dlg;
   return collection;
 }
 
@@ -511,7 +504,7 @@ QString CalendarSupport::displayName( Calendar *calendar, const Akonadi::Collect
   // Kolab Groupware
   if ( c.resource().contains( "kolabproxy" ) ) {
     QString typeStr = cName; // contents type: "Calendar", "Tasks", etc
-    QString ownerStr;        // folder owner; "fred", "ethel", etc
+    QString ownerStr;        // folder owner: "fred", "ethel", etc
     QString nameStr;         // folder name: "Public", "Test", etc
     if ( calendar ) {
       Akonadi::Collection p = c.parentCollection();
@@ -536,24 +529,75 @@ QString CalendarSupport::displayName( Calendar *calendar, const Akonadi::Collect
       if ( ownerStr.toUpper() != QString( "INBOX" ) ) {
         if ( nameStr.isEmpty() ) {
           return i18nc( "%1 is folder owner name, %2 is folder contents",
-                        "%1's %2", ownerStr, typeStr );
+                        "%1's Kolab %2", ownerStr, typeStr );
         } else {
           return i18nc( "%1 is folder owner name, %2 is folder name, %3 is folder contents",
-                        "%1's %2 %3", ownerStr, nameStr, typeStr );
+                        "%1's %2 Kolab %3", ownerStr, nameStr, typeStr );
         }
       } else {
         return i18nc( "%1 is folder contents",
-                      "My Shared %1", typeStr );
+                      "My Kolab %1", typeStr );
       }
     } else {
-      return typeStr;
+      return i18nc( "%1 is folder contents",
+                    "Kolab %1", typeStr );
     }
-  }
+  } //end kolab section
 
   // Dav Groupware
   if ( c.resource().contains( "davgroupware" ) ) {
     return i18nc( "%1 is the folder name", "%1 CalDav Calendar", cName );
-  }
+  } //end caldav section
+
+  // Google
+  if ( c.resource().contains( "google" ) ) {
+    QString ownerStr;        // folder owner: "user@gmail.com"
+    if ( calendar ) {
+      Akonadi::Collection p = c.parentCollection();
+      Akonadi::EntityDisplayAttribute *pattr =
+        calendar->collection( p.id() ).attribute<Akonadi::EntityDisplayAttribute>();
+      if ( pattr && !pattr->displayName().isEmpty() ) {
+        ownerStr = pattr->displayName();
+      }
+    }
+
+    const Akonadi::EntityDisplayAttribute *attr = c.attribute<Akonadi::EntityDisplayAttribute>();
+    QString nameStr;         // folder name: can be anything
+    if ( attr && !attr->displayName().isEmpty() ) {
+      nameStr = attr->displayName();
+    } else {
+      nameStr = cName;
+    }
+
+    QString typeStr;
+    const QString mimeStr = c.contentMimeTypes().join( "," );
+    if ( mimeStr.contains( ".event" ) ) {
+      typeStr = i18n( "Calendar" );
+    } else if ( mimeStr.contains( ".todo" ) ) {
+      typeStr = i18n( "Tasks" );
+    } else if ( mimeStr.contains( ".journal" ) ) {
+      typeStr = i18n( "Journal" );
+    } else if ( mimeStr.contains( ".note" ) ) {
+      typeStr = i18n( "Notes" );
+    } else {
+      typeStr = mimeStr;
+    }
+
+    if ( !ownerStr.isEmpty() ) {
+      const int atChar = ownerStr.lastIndexOf( '@' );
+      ownerStr = ownerStr.left( atChar );
+      if ( nameStr.isEmpty() ) {
+        return i18nc( "%1 is folder owner name, %2 is folder contents",
+                      "%1's Google %2", ownerStr, typeStr );
+      } else {
+        return i18nc( "%1 is folder owner name, %2 is folder name",
+                      "%1's %2", ownerStr, nameStr );
+      }
+    } else {
+      return i18nc( "%1 is folder contents",
+                    "Google %1", typeStr );
+    }
+  } //end google section
 
   // Not groupware so the collection is "mine"
   const Akonadi::EntityDisplayAttribute *attr = c.attribute<Akonadi::EntityDisplayAttribute>();
