@@ -18,11 +18,13 @@
 #include "thunderbirdsettings.h"
 #include <mailtransport/transportmanager.h>
 #include "mailcommon/mailutil.h"
+#include "importwizardutil.h"
 
 #include <kpimidentities/identity.h>
 #include <kpimidentities/signature.h>
+#include <KStandardDirs>
 
-
+#include <KABC/VCardConverter>
 #include <QTextStream>
 #include <QStringList>
 #include <QFile>
@@ -48,8 +50,11 @@ ThunderbirdSettings::ThunderbirdSettings( const QString& filename, ImportWizard
          line.contains(QLatin1String("mailnews."))||
          line.contains(QLatin1String("mail.compose."))||
          line.contains(QLatin1String("mail.spellcheck")) ||
+         line.contains(QLatin1String("mail.SpellCheckBeforeSend")) ||
+         line.contains(QLatin1String("spellchecker.dictionary")) ||
          line.contains(QLatin1String("ldap_")) ||
-         line.contains(QLatin1String("mail.biff."))) {
+         line.contains(QLatin1String("mail.biff.")) ||
+         line.contains(QLatin1String("mailnews.tags."))) {
         insertIntoMap( line );
       }
     } else {
@@ -64,12 +69,17 @@ ThunderbirdSettings::ThunderbirdSettings( const QString& filename, ImportWizard
   readAccount();
   readGlobalSettings();
   readLdapSettings();
+  readTagSettings();
 }
 
 ThunderbirdSettings::~ThunderbirdSettings()
 {
 }
 
+void ThunderbirdSettings::readTagSettings()
+{
+    ImportWizardUtil::addNepomukTag(mHashTag.values());
+}
 
 void ThunderbirdSettings::readLdapSettings()
 {
@@ -109,7 +119,7 @@ void ThunderbirdSettings::readLdapSettings()
         qDebug()<<" Security not implemented :"<<ldap.ldapUrl.scheme();
       }
     }
-    mergeLdap(ldap);
+    ImportWizardUtil::mergeLdap(ldap);
   }
 }
 
@@ -187,6 +197,20 @@ void ThunderbirdSettings::readGlobalSettings()
     //Default value in thunderbird
     addKmailConfig(QLatin1String("General"),QLatin1String("beep-on-mail"), true);
   }
+  const QString mailSpellCheckBeforeSendStr = QLatin1String("mail.SpellCheckBeforeSend");
+  if(mHashConfig.contains(mailSpellCheckBeforeSendStr)) {
+    const bool mailSpellCheckBeforeSend = mHashConfig.value(mailSpellCheckBeforeSendStr).toBool();
+    addKmailConfig(QLatin1String("Composer"),QLatin1String("check-spelling-before-send"), mailSpellCheckBeforeSend);
+  } else {
+    addKmailConfig(QLatin1String("Composer"),QLatin1String("check-spelling-before-send"), false);
+  }
+
+  const QString mailSpellCheckLanguageStr = QLatin1String("spellchecker.dictionary");
+  if(mHashConfig.contains(mailSpellCheckLanguageStr)) {
+    const QString mailSpellCheckLanguage = mHashConfig.value(mailSpellCheckLanguageStr).toString();
+    addKmailConfig(QLatin1String("Spelling"), QLatin1String("defaultLanguage"),mailSpellCheckLanguage);
+    //TODO create map to convert thunderbird name to aspell name
+  }
 }
 
 void ThunderbirdSettings::addAuth(QMap<QString, QVariant>& settings, const QString & argument, const QString &accountName )
@@ -371,11 +395,10 @@ void ThunderbirdSettings::readAccount()
       addToManualCheck(agentIdentifyName,true);
     } else if ( type == QLatin1String( "none" ) ) {
       //FIXME look at if we can implement it
-      //Local folder.
       kDebug()<<" account type none!";
     } else if (type == QLatin1String("movemail")) {
       kDebug()<<" movemail accound found and not implemented in importthunderbird";
-      //MailBox ?
+      //TODO
     } else if (type == QLatin1String("rss")) {
       //TODO when akregator2 will merge in kdepim
       kDebug()<<" rss resource needs to be implemented";
@@ -577,10 +600,25 @@ void ThunderbirdSettings::readIdentity( const QString& account )
   const QString attachVcardStr( identity + QLatin1String( ".attach_vcard" ) );
   if ( mHashConfig.contains( attachVcardStr ) ) {
     const bool attachVcard = mHashConfig.value( attachVcardStr ).toBool();
-    if ( attachVcard ) {
-      const QString vcardContent = mHashConfig.value( identity + QLatin1String( ".escapedVCard" ) ).toString();
-      //TODO: not implemented in kmail
-    }
+    newIdentity->setAttachVcard(attachVcard);
+  }
+  const QString attachVcardContentStr( identity + QLatin1String( ".escapedVCard" ) );
+  if( mHashConfig.contains( attachVcardContentStr ) ) {
+      const QString str = mHashConfig.value( attachVcardContentStr ).toString();
+      QByteArray vcard = QByteArray::fromPercentEncoding ( str.toLocal8Bit() );
+      KABC::VCardConverter converter;
+      KABC::Addressee addr = converter.parseVCard( vcard );
+
+      const QString filename = KStandardDirs::locateLocal("appdata",newIdentity->identityName() + QLatin1String(".vcf"));
+      QFile file(filename);
+      if ( file.open( QIODevice::WriteOnly |QIODevice::Text ) ) {
+        const QByteArray data = converter.exportVCard( addr, KABC::VCardConverter::v3_0 );
+        file.write( data );
+        file.flush();
+        file.close();
+        newIdentity->setVCardFile(filename);
+      }
+
   }
   const QString composeHtmlStr( identity + QLatin1String( ".compose_html" ) );
   //TODO: implement it in kmail
@@ -621,4 +659,23 @@ void ThunderbirdSettings::insertIntoMap( const QString& line )
     QString ldapAccountName = key;
     mLdapAccountList.append(ldapAccountName.remove(QLatin1String(".description")));
   }
+  if(key.contains(QLatin1String("mailnews.tags.")) &&
+          (key.endsWith(QLatin1String(".color")) || key.endsWith(QLatin1String(".tag")))) {
+      QString name = key;
+      name.remove(QLatin1String("mailnews.tags."));
+      name.remove(QLatin1String(".color"));
+      name.remove(QLatin1String(".tag"));
+      tagStruct tag;
+      if(mHashTag.contains(name)) {
+        tag = mHashTag.value(name);
+        mHashTag.remove(name);
+      }
+      if(key.endsWith(QLatin1String(".color"))) {
+        tag.color = QColor(mHashConfig.value(key).toString());
+      } else {
+        tag.name = mHashConfig.value(key).toString();
+      }
+      mHashTag.insert(name,tag);
+      kDebug()<<" tag :"<<name<<" tag.name"<<tag.name<<" color :"<<tag.color;
+  }
 }
