@@ -42,7 +42,8 @@
 
 #include <kleo/stl_util.h>
 
-#include <KLocalizedString>
+#include <KLocale>
+#include <KMessageBox>
 #include <kdebug.h>
 
 #include <QStringList>
@@ -171,7 +172,7 @@ void DecryptVerifyFilesCommand::doCancel() {
 }
 
 QStringList DecryptVerifyFilesCommand::Private::selectFiles() const {
-    return FileDialog::getOpenFileNames( parentWidgetOrView(), i18n( "Select One or More Files to Decrypt and/or Verify" ), QLatin1String("enc") );
+    return FileDialog::getOpenFileNames( parentWidgetOrView(), i18n( "Select One or More Files to Decrypt and/or Verify" ), "enc" );
 }
 
 #undef d
