@@ -30,7 +30,9 @@
     your version.
 */
 
+#if !defined(QT_STL)
 #define QT_STL
+#endif
 
 #include <config-kleopatra.h>
 
