@@ -1,5 +1,6 @@
 /*
  * This file is part of KMail.
+ * Copyright (c) 2012 Laurent Montel <montel@kde.org>
  * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
  *
  * Parts based on KMail code by:
@@ -24,9 +25,10 @@
 #ifndef KMAIL_ATTACHMENTVIEW_H
 #define KMAIL_ATTACHMENTVIEW_H
 
-#include <QtGui/QTreeView>
+#include <QTreeView>
 
 class QContextMenuEvent;
+class QToolButton;
 
 namespace Message {
 class AttachmentModel;
@@ -43,6 +45,8 @@ class AttachmentView : public QTreeView
     explicit AttachmentView( Message::AttachmentModel *model, QWidget *parent = 0 );
     ~AttachmentView();
 
+    QWidget *widget();
+
   public slots:
     /// model sets these
     void setEncryptEnabled( bool enabled );
@@ -50,6 +54,7 @@ class AttachmentView : public QTreeView
     void hideIfEmpty();
     void selectNewAttachment();
 
+    void updateAttachmentLabel();
   protected:
     /** reimpl to avoid default drag cursor */
     virtual void startDrag( Qt::DropActions supportedActions );
@@ -60,6 +65,8 @@ class AttachmentView : public QTreeView
     /** reimpl to avoid drags from ourselves */
     virtual void dragEnterEvent( QDragEnterEvent *event );
 
+  private Q_SLOTS:
+    void slotShowHideAttchementList(bool);
   private:
     void saveHeaderState();
     void restoreHeaderState();
