@@ -34,7 +34,6 @@ class QPushButton;
 class QLabel;
 class QCheckBox;
 class QFont;
-class QRegExpValidator;
 class QPoint;
 class QGroupBox;
 class QSpinBox;
@@ -367,6 +366,7 @@ private:
 
 private: // data
   QCheckBox *mCloseAfterReplyOrForwardCheck;
+  QCheckBox *mAccessKeyEnabled;
   MessageViewer::ConfigureWidget *mViewerSettings;
 };
 
@@ -650,7 +650,6 @@ private:
 private:
   QCheckBox   *mCreateOwnMessageIdCheck;
   KLineEdit   *mMessageIdSuffixEdit;
-  QRegExpValidator *mMessageIdSuffixValidator;
   ListView    *mTagList;
   QPushButton *mRemoveHeaderButton;
   KLineEdit   *mTagNameEdit;
