@@ -328,7 +328,6 @@ class KMComposeWin : public KMail::Composer
     void slotCopy();
     void slotPaste();
     void slotPasteAsAttachment();
-    void slotFormatReset();
     void slotMarkAll();
     void slotTranslatorWasClosed();
 
@@ -531,10 +530,6 @@ class KMComposeWin : public KMail::Composer
      */
     virtual bool queryClose();
 
-    /**
-     * prevent kmail from exiting when last window is deleted (kernel rules)
-     */
-    virtual bool queryExit();
     /**
      * Turn encryption on/off. If setByUser is true then a message box is shown
      * in case encryption isn't possible.
@@ -632,14 +627,12 @@ class KMComposeWin : public KMail::Composer
     KToggleAction *mDictionaryAction, *mSnippetAction, *mTranslateAction;
 
     KToggleAction *markupAction;
-    KAction *actionFormatReset;
 
     CodecAction *mCodecAction;
     KSelectAction *mCryptoModuleAction;
 
     KAction *mFindText, *mFindNextText, *mReplaceText, *mSelectAll;
   
-    QFont mSaveFont;
     QSplitter *mHeadersToEditorSplitter;
     QWidget* mHeadersArea;
     QSplitter *mSplitter;
