@@ -131,7 +131,6 @@ KMKernel::KMKernel (QObject *parent, const char *name) :
   setObjectName( name );
   mySelf = this;
   the_startingUp = true;
-  closed_by_user = true;
   the_firstInstance = true;
 
   the_undoStack = 0;
@@ -570,7 +569,7 @@ void KMKernel::openReader( bool onlyCheck )
 
   bool activate;
   if (ktmw) {
-    mWin = (KMMainWin *) ktmw;
+    mWin = static_cast<KMMainWin *>(ktmw);
     activate = !onlyCheck; // existing window: only activate if not --check
     if ( activate )
        mWin->show();
@@ -1615,8 +1614,9 @@ bool KMKernel::canQueryClose()
   if ( mSystemTray->mode() == GlobalSettings::EnumSystemTrayPolicy::ShowAlways ) {
     mSystemTray->hideKMail();
     return false;
-  } else if ( ( mSystemTray->mode() == GlobalSettings::EnumSystemTrayPolicy::ShowOnUnread ) && ( mSystemTray->hasUnreadMail() )) {
-    mSystemTray->setStatus( KStatusNotifierItem::Active );
+  } else if ( ( mSystemTray->mode() == GlobalSettings::EnumSystemTrayPolicy::ShowOnUnread ) ) {
+    if( mSystemTray->hasUnreadMail() )
+      mSystemTray->setStatus( KStatusNotifierItem::Active );
     mSystemTray->hideKMail();
     return false;
   }
