@@ -88,14 +88,6 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
   public:
     typedef QList<KMMainWidget*> PtrList;
 
-    enum PropsPage
-    {
-      PropsGeneral,
-      PropsShortcut,
-      PropsMailingList,
-      PropsExpire
-    };
-
     KMMainWidget(QWidget *parent, KXMLGUIClient *aGUIClient,
                  KActionCollection *actionCollection,
                  KSharedConfig::Ptr config = KMKernel::self()->config() );
@@ -140,11 +132,6 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     */
     static const PtrList *mainWidgetList();
 
-    /**
-      Return the list of all action, in order to check shortcuts conflicts against them.
-    */
-    QList<QAction*> actionList();
-
     QLabel* vacationScriptIndicator() const;
     void updateVacationScriptStatus() { updateVacationScriptStatus( mVacationIndicatorActive ); }
 
@@ -513,6 +500,8 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
 
     void showMessagePopup(const Akonadi::Item&msg ,const KUrl&aUrl,const KUrl &imageUrl,const QPoint& aPoint, bool contactAlreadyExists, bool uniqueContactFound);
 
+    void showCollectionProperties( const QString &pageToShow );
+    void showCollectionPropertiesContinued( const QString &pageToShow );
 
   private slots:
     /**
@@ -538,6 +527,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     void itemsFetchDone( KJob *job );
 
     void slotCollectionPropertiesContinued( KJob* job );
+    void slotCollectionPropertiesFinished( KJob *job );
     void slotDeletionCollectionResult(KJob* job);
     void slotServerSideSubscription();
     void slotFetchItemsForFolderDone(KJob*job);
@@ -603,7 +593,7 @@ private:
     KActionCollection *mActionCollection;
     QAction *mToolbarActionSeparator;
     QVBoxLayout *mTopLayout;
-    bool mDestructed, mForceJumpToUnread, mShowingOfflineScreen;
+    bool mDestructed, mShowingOfflineScreen;
     QList<QAction*> mFilterMenuActions;
     QList<QAction*> mFilterTBarActions;
     QList<KMMetaFilterActionCommand*> mFilterCommands;
