@@ -22,22 +22,34 @@
 #include "messagetag.h"
 
 #include <soprano/nao.h>
-#include <Nepomuk/Tag>
-#include <Nepomuk/Variant>
-
+#include <Nepomuk2/Tag>
+#include <Nepomuk2/Variant>
+#include <QDebug>
 using namespace KMail;
 
-Tag::Ptr Tag::fromNepomuk( const Nepomuk::Tag& nepomukTag )
+Tag::Ptr Tag::fromNepomuk( const Nepomuk2::Tag& nepomukTag )
 {
   Tag::Ptr tag( new Tag() );
   tag->tagName = nepomukTag.label();
 
-  if ( nepomukTag.symbols().isEmpty() )
+  tag->iconName = nepomukTag.genericIcon();
+  if ( tag->iconName.isEmpty() )
     tag->iconName = "mail-tagged";
-  else
-    tag->iconName = nepomukTag.symbols().first();
 
-  tag->nepomukResourceUri = nepomukTag.resourceUri();
+  tag->nepomukResourceUri = nepomukTag.uri();
+
+  const QString identifier = nepomukTag.property( Soprano::Vocabulary::NAO::identifier() ).toString();
+  tag->tagStatus = (identifier == QLatin1String("important")) ||
+          (identifier == QLatin1String("todo")) ||
+          (identifier == QLatin1String("watched")) ||
+          (identifier == QLatin1String("deleted")) ||
+          (identifier == QLatin1String("spam")) ||
+          (identifier == QLatin1String("replied")) ||
+          (identifier == QLatin1String("ignored")) ||
+          (identifier == QLatin1String("forwarded")) ||
+          (identifier == QLatin1String("sent")) ||
+          (identifier == QLatin1String("queued")) ||
+          (identifier == QLatin1String("ham"));
 
   if ( nepomukTag.hasProperty( Vocabulary::MessageTag::textColor() ) ) {
     const QString name = nepomukTag.property( Vocabulary::MessageTag::textColor() ).toString();
@@ -77,11 +89,11 @@ Tag::Ptr Tag::fromNepomuk( const Nepomuk::Tag& nepomukTag )
 
 void Tag::saveToNepomuk( SaveFlags saveFlags ) const
 {
-  Nepomuk::Tag nepomukTag( nepomukResourceUri );
+  Nepomuk2::Tag nepomukTag( nepomukResourceUri );
 
   nepomukTag.setLabel( tagName );
 
-  Nepomuk::Resource symbol( QUrl(), Soprano::Vocabulary::NAO::FreeDesktopIcon() );
+  Nepomuk2::Resource symbol( QUrl(), Soprano::Vocabulary::NAO::FreeDesktopIcon() );
   symbol.setProperty( Soprano::Vocabulary::NAO::iconName(), iconName );
 
   nepomukTag.setProperty( Soprano::Vocabulary::NAO::hasSymbol(), symbol );
