@@ -21,11 +21,15 @@
 
 #include "filteractionmissingargumentdialog.h"
 
-#ifndef KDEPIM_NO_NEPOMUK
-#include <nepomuk/tag.h>
-#endif
+#include <Nepomuk2/Tag>
+#include <Nepomuk2/Resource>
+#include <Nepomuk2/Query/ResourceTypeTerm>
+#include <Nepomuk2/Query/QueryServiceClient>
+#include <Nepomuk2/Query/Result>
+#include <Soprano/Vocabulary/NAO>
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
+#include <QPointer>
 
 using namespace MailCommon;
 
@@ -47,45 +51,60 @@ bool FilterActionAddTag::isEmpty() const
 
 void FilterActionAddTag::initializeTagList()
 {
-#ifndef KDEPIM_NO_NEPOMUK
-  foreach( const Nepomuk::Tag &tag, Nepomuk::Tag::allTags() ) {
-    mParameterList.append( tag.label() );
-    mLabelList.append( tag.resourceUri().toString() );
+  mTagQueryClient = new Nepomuk2::Query::QueryServiceClient(this);
+  connect( mTagQueryClient, SIGNAL(newEntries(QList<Nepomuk2::Query::Result>)),
+           this, SLOT(newTagEntries(QList<Nepomuk2::Query::Result>)) );
+  connect( mTagQueryClient, SIGNAL(finishedListing()),
+           this, SLOT(finishedTagListing()) );
+
+  Nepomuk2::Query::ResourceTypeTerm term( Soprano::Vocabulary::NAO::Tag() );
+  Nepomuk2::Query::Query query( term );
+  mTagQueryClient->query(query);
+ }
+
+void FilterActionAddTag::newTagEntries( const QList<Nepomuk2::Query::Result> &results )
+{
+  foreach(const Nepomuk2::Query::Result &result, results ) {
+    Nepomuk2::Resource resource = result.resource();
+    mParameterList.append( resource.label() );
+    mLabelList.append( resource.uri().toString( ));
   }
-#endif
 }
 
+void FilterActionAddTag::finishedTagListing()
+{
+  mTagQueryClient->deleteLater();
+  mTagQueryClient = 0;
+}
+
+
 bool FilterActionAddTag::argsFromStringInteractive( const QString &argsStr, const QString& filterName )
 {
   bool needUpdate = false;
   argsFromString( argsStr );
   if( mParameterList.isEmpty() )
     return false;
-#ifndef KDEPIM_NO_NEPOMUK
   const int index = mParameterList.indexOf( mParameter );
   if ( index == -1 ) {
-    FilterActionMissingTagDialog *dlg = new FilterActionMissingTagDialog( mParameterList, filterName, argsStr );
+    QPointer<FilterActionMissingTagDialog> dlg = new FilterActionMissingTagDialog( mParameterList, filterName, argsStr );
     if ( dlg->exec() ) {
       mParameter = dlg->selectedTag();
       needUpdate = true;
     }
     delete dlg;
   }
-#endif
   return needUpdate;
 }
 
 
 FilterAction::ReturnCode FilterActionAddTag::process( ItemContext &context ) const
 {
-#ifndef KDEPIM_NO_NEPOMUK
   const int index = mParameterList.indexOf( mParameter );
   if ( index == -1 )
     return ErrorButGoOn;
 
-  Nepomuk::Resource resource( context.item().url() );
+  Nepomuk2::Resource resource( context.item().url() );
   resource.addTag( mParameter );
-#endif
 
   return GoOn;
 }
@@ -126,3 +145,5 @@ QString FilterActionAddTag::displayString() const
 {
   return label() + QLatin1String( " \"" ) + Qt::escape( argsAsString() ) + QLatin1String( "\"" );
 }
+
+#include "filteractionaddtag.moc"
