@@ -33,6 +33,8 @@
 #include "signencryptjob.h"
 #include "skeletonmessagejob.h"
 #include "transparentjob.h"
+#include "autoimageresizing/autoresizeimagejob.h"
+
 
 #include <QTimer>
 
@@ -510,18 +512,31 @@ AttachmentPart::List Composer::attachmentParts() const
   return d->attachmentParts;
 }
 
-void Composer::addAttachmentPart( AttachmentPart::Ptr part )
+void Composer::addAttachmentPart( AttachmentPart::Ptr part, bool autoresizeImage )
 {
   Q_D( Composer );
   Q_ASSERT( !d->started );
   Q_ASSERT( !d->attachmentParts.contains( part ) );
+  if( autoresizeImage ) {
+      if(part->mimeType() == "image/gif" ||
+              part->mimeType() == "image/jpeg" ||
+              part->mimeType() == "image/png" ) {
+          AutoResizeImageJob *autoResizeJob = new AutoResizeImageJob(this);
+          if(autoResizeJob->loadImageFromData(part->data())) {
+            if(autoResizeJob->resizeImage()) {
+              part->setData(autoResizeJob->imageArray());
+            }
+          }
+          delete autoResizeJob;
+      }
+  }
   d->attachmentParts.append( part );
 }
 
-void Composer::addAttachmentParts( const AttachmentPart::List &parts )
+void Composer::addAttachmentParts(const AttachmentPart::List &parts , bool autoresizeImage)
 {
   foreach( AttachmentPart::Ptr part, parts ) {
-    addAttachmentPart( part );
+    addAttachmentPart( part, autoresizeImage );
   }
 }
 
