@@ -98,6 +98,7 @@ Message::ComposerViewBase::ComposerViewBase ( QObject* parent, QWidget *parentGu
  , m_cryptoMessageFormat( Kleo::AutoFormat )
  , m_pendingQueueJobs( 0 )
  , m_autoSaveTimer( 0 )
+ , m_autoSaveErrorShown( false )
  , m_autoSaveInterval( 1 * 1000 * 60 ) // default of 1 min
 {
   m_charsets << "utf-8"; // default, so we have a backup in case client code forgot to set.
@@ -269,7 +270,7 @@ void Message::ComposerViewBase::send ( MessageSender::SendMethod method, Message
     }
     if ( KMessageBox::No == ret ) {
       m_encrypt = false;
-      m_encrypt = false;
+      m_sign = false;
     } else {
       emit disableHtml( NoConfirmationNeeded );
     }
@@ -386,13 +387,26 @@ void Message::ComposerViewBase::slotEmailAddressResolved ( KJob* job )
     return;
   }
 
+  bool autoresizeImage = false;
+  if(MessageComposer::MessageComposerSettings::self()->autoResizeImageEnabled()) {
+    if(MessageComposer::MessageComposerSettings::self()->askBeforeResizing()) {
+#if 0
+       const int rc = KMessageBox::warningYesNo( parent,i18n("Do you want to resize images?"),
+                                                 i18n("Auto Resize Images"), KStandardGuiItem::yes(), KStandardGuiItem::no());
+       if(rc == KMessageBox::Yes) {
+           autoresizeImage = true;
+         //TODO
+       }
+#endif
+    }
+  }
   // Compose each message and prepare it for queueing, sending, or storing
   foreach( Message::Composer* composer, m_composers ) {
     fillGlobalPart( composer->globalPart() );
     m_editor->fillComposerTextPart( composer->textPart() );
     fillInfoPart( composer->infoPart(), UseExpandedRecipients );
 
-    composer->addAttachmentParts( m_attachmentModel->attachments() );
+    composer->addAttachmentParts( m_attachmentModel->attachments(), autoresizeImage );
 
     connect( composer, SIGNAL(result(KJob*)), this, SLOT(slotSendComposeResult(KJob*)) );
     composer->start();
@@ -1511,12 +1525,10 @@ bool Message::ComposerViewBase::hasMissingAttachments( const QStringList& attach
                QString::fromLatin1("\\b") );
   rx.setCaseSensitivity( Qt::CaseInsensitive );
 
-  bool gotMatch = false;
-
   // check whether the subject contains one of the attachment key words
   // unless the message is a reply or a forwarded message
   const QString subj = subject();
-  gotMatch = ( MessageHelper::stripOffPrefixes( subj ) == subj ) && ( rx.indexIn( subj ) >= 0 );
+  bool gotMatch = ( MessageHelper::stripOffPrefixes( subj ) == subj ) && ( rx.indexIn( subj ) >= 0 );
 
   if ( !gotMatch ) {
     // check whether the non-quoted text contains one of the attachment key
