@@ -58,6 +58,7 @@ class KMeditorPrivate
     KMeditorPrivate( KMeditor *parent )
      : q( parent ),
        useExtEditor( false ),
+       forcePlainTextMarkup( false ),
        mExtEditorProcess( 0 ),
        mExtEditorTempFile( 0 ),
        mAutoCorrection( 0 )
@@ -107,7 +108,7 @@ class KMeditorPrivate
     QString extEditorPath;
     KMeditor *q;
     bool useExtEditor;
-    
+    bool forcePlainTextMarkup;
     QString quotePrefix;
 
     KProcess *mExtEditorProcess;
@@ -212,7 +213,7 @@ void KMeditorPrivate::startExternalEditor()
                     q, SLOT(slotEditorFinished(int,QProcess::ExitStatus)) );
   mExtEditorProcess->start();
   if ( !mExtEditorProcess->waitForStarted() ) {
-    //TODO: messagebox
+    KMessageBox::error(q->topLevelWidget(),i18n("External editor can not be started. Please verify command \"%1\"",commandLine));
     mExtEditorProcess->deleteLater();
     mExtEditorProcess = 0;
     delete mExtEditorTempFile;
@@ -438,7 +439,7 @@ void KMeditor::slotAddQuotes()
 QString KMeditorPrivate::addQuotesToText( const QString &inputText )
 {
   QString answer = QString( inputText );
-  QString indentStr = q->defaultQuoteSign();
+  const QString indentStr = q->defaultQuoteSign();
   answer.replace( QLatin1Char( '\n' ), QLatin1Char( '\n' ) + indentStr );
   //cursor.selectText() as QChar::ParagraphSeparator as paragraph separator.
   answer.replace( QChar::ParagraphSeparator, QLatin1Char( '\n' ) + indentStr );
@@ -772,9 +773,10 @@ void KMeditor::fillComposerTextPart ( TextPart* textPart ) const
     Grantlee::MarkupDirector *pmd = new Grantlee::MarkupDirector( pb );
     pmd->processDocument( document() );
     const QString plainText = pb->getResult();
-    //qDebug()<<" plainText :"<<plainText;
     textPart->setCleanPlainText( toCleanPlainText(plainText) );
     QTextDocument *doc = new QTextDocument(plainText);
+    doc->adjustSize();
+    
     textPart->setWrappedPlainText(toWrappedPlainText(doc));
     delete doc;
     delete pmd;
@@ -809,5 +811,29 @@ void KMeditor::setAutocorrectionLanguage(const QString& lang)
   d->mAutoCorrection->setLanguage(lang);
 }
 
+void KMeditor::forcePlainTextMarkup(bool force)
+{
+  d->forcePlainTextMarkup = force;
+}
+
+void KMeditor::insertPlainTextImplementation()
+{
+#ifdef GRANTLEE_GREATER_0_2
+  if( d->forcePlainTextMarkup ) {
+    Grantlee::PlainTextMarkupBuilder *pb = new Grantlee::PlainTextMarkupBuilder();
+
+    Grantlee::MarkupDirector *pmd = new Grantlee::MarkupDirector( pb );
+    pmd->processDocument( document() );
+    const QString plainText = pb->getResult();
+    document()->setPlainText(plainText);
+    delete pmd;
+    delete pb;
+  } else {
+    document()->setPlainText(document()->toPlainText());
+  }
+#else
+  document()->setPlainText(document()->toPlainText()); 
+#endif
+}
 
 #include "kmeditor.moc"
