@@ -338,11 +338,6 @@ public:
    */
   bool selectFirstMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem );
 
-  /**
-   * Fills menu by adding actions for manipulating the view.
-   */
-  void fillViewMenu( KMenu * menu );
-
   /**
    * Sets the focus on the quick search line of the currently active tab.
    */
@@ -364,6 +359,13 @@ public:
    */
   virtual void setRowHidden( int row, const QModelIndex & parent, bool hide );
 
+  void sortOrderMenuAboutToShow(KMenu *menu);
+
+  void aggregationMenuAboutToShow(KMenu *menu);
+
+  void themeMenuAboutToShow(KMenu *menu);
+
+
 protected:
   /**
    * Reimplemented in order to catch QHelpEvent
@@ -502,7 +504,7 @@ protected:
    * Returns 0 if the view is empty.
    */
   Item * firstMessageItem( MessageTypeFilter messageTypeFilter )
-    { return messageItemAfter( 0, messageTypeFilter, false ); };
+    { return messageItemAfter( 0, messageTypeFilter, false ); }
 
   /**
    * Finds the previous message item with respect to the current item.
@@ -543,7 +545,7 @@ protected:
    * Returns 0 if the view is empty.
    */
   Item * lastMessageItem( MessageTypeFilter messageTypeFilter )
-    { return messageItemBefore( 0, messageTypeFilter, false ); };
+    { return messageItemBefore( 0, messageTypeFilter, false ); }
 
   /**
    * This is called by Model to signal a start of a lengthy job batch.
