@@ -31,11 +31,11 @@
 #include <core/settings.h>
 
 #include <QtCore/QTimer>
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
-#include <QtGui/QDrag>
-#include <QtGui/QDragMoveEvent>
-#include <QtGui/QDropEvent>
+#include <QAction>
+#include <QApplication>
+#include <QDrag>
+#include <QDragMoveEvent>
+#include <QDropEvent>
 
 #include <KDE/KActionCollection>
 #include <KDE/KComboBox>
@@ -48,7 +48,7 @@
 #include <KDE/KXMLGUIClient>
 #include <KDE/KXMLGUIFactory>
 
-#include <Nepomuk/Tag>
+#include <Nepomuk2/Tag>
 #include "core/groupheaderitem.h"
 
 namespace MessageList
@@ -196,14 +196,14 @@ void Widget::fillMessageTagCombo( KComboBox * combo )
     return;
   }
   const QStringList tagSelectedLst = tagSelected.split(QLatin1String(","));
-  foreach( const Nepomuk::Tag &nepomukTag, Nepomuk::Tag::allTags() ) {
-    const QString id = nepomukTag.resourceUri().toString();
+  foreach( const Nepomuk2::Tag &nepomukTag, Nepomuk2::Tag::allTags() ) {
+    const QString id = nepomukTag.uri().toString();
     if(tagSelectedLst.contains(id)) {
-      QString iconName = QLatin1String( "mail-tagged" );
+      QString iconName = nepomukTag.genericIcon(); 
+      if(iconName.isEmpty()) 
+        iconName = QLatin1String( "mail-tagged" ); 
       const QString label = nepomukTag.label();
-      if ( !nepomukTag.symbols().isEmpty() )
-        iconName = nepomukTag.symbols().first();
-      const QString id = nepomukTag.resourceUri().toString();
+      const QString id = nepomukTag.uri().toString();
       combo->addItem( SmallIcon( iconName ), label, QVariant( id ) );
     }
   }
