@@ -35,6 +35,7 @@
 #include <QtCore/QObject>
 #include <QtCore/QTimer>
 #include <QMouseEvent>
+#include <QWebElement>
 
 namespace GpgME { class Error; }
 namespace KIO { 
@@ -359,6 +360,8 @@ public:
   /** View message part of type message/RFC822 in extra viewer window. */
   void atmViewMsg( KMime::Message::Ptr message );
 
+  void setExternalWindow( bool b );
+
   void adjustLayout();
   void createWidgets();
   void createActions();
@@ -452,6 +455,7 @@ public:
 
 
 private slots:
+  void slotToggleCaretBrowsing(bool);
   void slotAtmDecryptWithChiasmusResult( const GpgME::Error &, const QVariant & );
   void slotAtmDecryptWithChiasmusUploadResult( KJob * );
 
@@ -648,6 +652,11 @@ public:
   KToggleAction *mHeaderOnlyAttachmentsAction;
   KSelectAction *mSelectEncodingAction;
   KToggleAction *mToggleFixFontAction, *mToggleDisplayModeAction;
+#ifndef KDEPIM_NO_WEBKIT
+#if QTWEBKIT_VERSION >= QTWEBKIT_VERSION_CHECK(2, 3, 0)
+  KToggleAction *mCaretBrowsing;
+#endif
+#endif
   KAction *mZoomTextOnlyAction, *mZoomInAction, *mZoomOutAction, *mZoomResetAction;
   KToggleAction *mToggleMimePartTreeAction;
   KAction *mSpeakTextAction;
