@@ -80,9 +80,9 @@
 
 #include <QtCore/QTimer>
 #include <QtDBus/QDBusConnection>
-#include <QtDeclarative/QDeclarativeEngine>
-#include <QtDeclarative/QDeclarativeContext>
-#include <QtGui/QGraphicsItem>
+#include <QDeclarativeEngine>
+#include <QDeclarativeContext>
+#include <QGraphicsItem>
 
 #ifdef Q_OS_WINCE
 class WinCEColorDialog : public KDialog
